@@ -174,21 +174,21 @@ sub fingerprint {
       && return $query;
 
    # -----------------------------------------------------------
-   # Remove quoted strings 
+   # Remove quoted strings
    # -----------------------------------------------------------
-   $query =~ s/([^\\])(\\')/$1/sg;    
-   $query =~ s/([^\\])(\\")/$1/sg;    
-   $query =~ s/\\\\//sg;              
-   $query =~ s/\\'//sg;               
-   $query =~ s/\\"//sg;                        
-   $query =~ s/([^\\])(".*?[^\\]?")/$1?/sg;    
-   $query =~ s/([^\\])('.*?[^\\]?')/$1?/sg;    
+   $query =~ s/([^\\])(\\')/$1/sg;
+   $query =~ s/([^\\])(\\")/$1/sg;
+   $query =~ s/\\\\//sg;
+   $query =~ s/\\'//sg;
+   $query =~ s/\\"//sg;
+   $query =~ s/([^\\])(".*?[^\\]?")/$1?/sg;
+   $query =~ s/([^\\])('.*?[^\\]?')/$1?/sg;
    # -----------------------------------------------------------
 
-   $query =~ s/\bfalse\b|\btrue\b/?/isg; # boolean values 
+   $query =~ s/\bfalse\b|\btrue\b/?/isg; # boolean values
 
-   # MD5 checksums which are always 32 hex chars 
-   if ( $self->{match_md5_checksums} ) { 
+   # MD5 checksums which are always 32 hex chars
+   if ( $self->{match_md5_checksums} ) {
       $query =~ s/([._-])[a-f0-9]{32}/$1?/g;
    }
 
@@ -204,7 +204,7 @@ sub fingerprint {
 
    # Clean up leftovers
    if ( $self->{match_md5_checksums} ) {
-      $query =~ s/[xb+-]\?/?/g;                
+      $query =~ s/[xb+-]\?/?/g;
    }
    else {
       $query =~ s/[xb.+-]\?/?/g;
@@ -270,11 +270,11 @@ sub distill_verbs {
       return $query;
    }
 
-   # All other, more complex verbs. 
+   # All other, more complex verbs.
    $query = $self->strip_comments($query);
 
    # SHOW statements are either 2 or 3 words: SHOW A (B), where A and B
-   # are words; B is optional.  E.g. "SHOW TABLES" or "SHOW SLAVE STATUS". 
+   # are words; B is optional.  E.g. "SHOW TABLES" or "SHOW SLAVE STATUS".
    # There's a few common keywords that may show up in place of A, so we
    # remove them first.  Then there's some keywords that signify extra clauses
    # that may show up in place of B and since these clauses are at the
@@ -300,7 +300,7 @@ sub distill_verbs {
       return $query;
    }
 
-   # Data defintion statements verbs like CREATE and ALTER.
+   # Data definition statements verbs like CREATE and ALTER.
    # The two evals are a hack to keep Perl from warning that
    # "QueryParser::data_def_stmts" used only once: possible typo at...".
    # Some day we'll group all our common regex together in a packet and
@@ -313,7 +313,7 @@ sub distill_verbs {
       $query =~ s/\s+IF(?:\s+NOT)?\s+EXISTS/ /i;
       my ( $obj ) = $query =~ m/$dds.+(DATABASE|TABLE)\b/i;
       $obj = uc $obj if $obj;
-      PTDEBUG && _d('Data def statment:', $dds, 'obj:', $obj);
+      PTDEBUG && _d('Data def statement:', $dds, 'obj:', $obj);
       my ($db_or_tbl)
          = $query =~ m/(?:TABLE|DATABASE)\s+($QueryParser::tbl_ident)(\s+.*)?/i;
       PTDEBUG && _d('Matches db or table:', $db_or_tbl);
@@ -343,7 +343,7 @@ sub distill_verbs {
       @verbs    = $union ? qw(SELECT UNION) : qw(SELECT);
    }
 
-   # This used to be "my $verbs" but older verisons of Perl complain that
+   # This used to be "my $verbs" but older versions of Perl complain that
    # ""my" variable $verbs masks earlier declaration in same scope" where
    # the earlier declaration is our $verbs.
    # http://code.google.com/p/maatkit/issues/detail?id=957
@@ -397,7 +397,7 @@ sub distill {
 
       if ( $verbs && $verbs =~ m/^SHOW/ ) {
          # Ignore tables for SHOW statements and normalize some
-         # aliases like SCHMEA==DATABASE, KEYS==INDEX.
+         # aliases like SCHEMA==DATABASE, KEYS==INDEX.
          my %alias_for = qw(
             SCHEMA   DATABASE
             KEYS     INDEX
@@ -412,8 +412,8 @@ sub distill {
       else {
          # For everything else, distill the tables.
          my @tables = $self->__distill_tables($query, $table, %args);
-         $query     = join(q{ }, $verbs, @tables); 
-      } 
+         $query     = join(q{ }, $verbs, @tables);
+      }
    }
 
    if ( $args{trf} ) {
@@ -427,7 +427,7 @@ sub convert_to_select {
    my ( $self, $query ) = @_;
    return unless $query;
 
-   # Trying to convert statments that have subqueries as values to column
+   # Trying to convert statements that have subqueries as values to column
    # assignments doesn't work.  E.g. SET col=(SELECT ...).  But subqueries
    # do work in other cases like JOIN (SELECT ...).
    # http://code.google.com/p/maatkit/issues/detail?id=347
